@@ -282,7 +282,10 @@ public:
   void change_relationship_name(const Glib::ustring& table_name, const Glib::ustring& name, const Glib::ustring& name_new);
 
   typedef std::vector< sharedptr<TableInfo> > type_listTableInfo;
-  type_listTableInfo get_tables(bool plus_system_prefs = false) const;
+  type_listTableInfo get_tables(bool plus_system_prefs = false);
+
+  typedef std::vector< sharedptr<const TableInfo> > type_listConstTableInfo;
+  type_listConstTableInfo get_tables(bool plus_system_prefs = false) const;
   std::vector<Glib::ustring> get_table_names(bool plus_system_prefs = false) const;
 
   void set_tables(const type_listTableInfo& tables);
@@ -541,7 +544,6 @@ private:
   public:
     Glib::ustring m_layout_name;
     Glib::ustring m_layout_platform; //Empty string (meaning normal platforms), or "maemo", or something else.
-    Glib::ustring m_parent_table;
 
     type_list_layout_groups m_layout_groups;
   };
@@ -556,42 +558,6 @@ private:
       m_info = sharedptr<TableInfo>(new TableInfo()); //Avoid a null sharedptr.
     }
 
-    //TODO: Avoid the use of this:
-    DocumentTableInfo(const DocumentTableInfo& src)
-      : m_info(src.m_info),
-        m_fields(src.m_fields),
-        m_relationships(src.m_relationships),
-        m_layouts(src.m_layouts),
-        m_reports(src.m_reports),
-        m_print_layouts(src.m_print_layouts),
-        m_example_rows(src.m_example_rows),
-        m_map_current_record(src.m_map_current_record),
-        m_layout_current(src.m_layout_current),
-        m_foundset_current(src.m_foundset_current),
-        m_overviewx(src.m_overviewx),
-        m_overviewy(src.m_overviewy)
-    {
-    }
-
-    //TODO: Avoid the use of this:
-    DocumentTableInfo& operator=(const DocumentTableInfo& src)
-    {
-      m_info = src.m_info;
-      m_fields = src.m_fields;
-      m_relationships = src.m_relationships;
-      m_layouts = src.m_layouts;
-      m_reports = src.m_reports;
-      m_print_layouts = src.m_print_layouts;
-      m_example_rows = src.m_example_rows;
-      m_map_current_record = src.m_map_current_record;
-      m_layout_current = src.m_layout_current;
-      m_foundset_current = src.m_foundset_current;
-      m_overviewx = src.m_overviewx;
-      m_overviewy = src.m_overviewy;
-
-      return *this;
-    }
-
     sharedptr<TableInfo> m_info;
 
     type_vec_fields m_fields;
@@ -616,11 +582,19 @@ private:
     FoundSet m_foundset_current;
 
     float m_overviewx, m_overviewy;
+
+  private:
+    //Prevent copying:
+    DocumentTableInfo(const DocumentTableInfo& src);
+    DocumentTableInfo& operator=(const DocumentTableInfo& src);
   };
 
-  DocumentTableInfo& get_table_info_with_add(const Glib::ustring& table_name);
+  sharedptr<DocumentTableInfo> get_table_info_with_add(const Glib::ustring& table_name);
 
-  typedef std::map<Glib::ustring, DocumentTableInfo> type_tables;
+  sharedptr<DocumentTableInfo> get_table_info(const Glib::ustring& table_name);
+  sharedptr<const DocumentTableInfo> get_table_info(const Glib::ustring& table_name) const;
+
+  typedef std::map<Glib::ustring, sharedptr<DocumentTableInfo> > type_tables;
   type_tables m_tables;
 
 
