@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_DIALOG_FLOWTABLE_H
@@ -46,8 +46,12 @@ public:
 
   void set_flowtable(FlowTableWithFields* flowtable);
   
-  gint get_columns_count(); //TODO: Make const?
-  Glib::ustring get_title(); //TODO: Isn't this the same as Widget::get_title()?
+  gint get_columns_count() const;
+
+  //TODO: Isn't this the same as Window::get_title()?
+  //  Probably, yes, at least when it is properly const.
+  //  so, TODO: find out what calls it.
+  Glib::ustring get_title();
     
 private:
   Gtk::Entry* m_entry_title;
